@@ -7,9 +7,9 @@
 #ifndef WT_DBO_DBACTION_IMPL_H_
 #define WT_DBO_DBACTION_IMPL_H_
 
-#include <Wt/Dbo/Exception>
+#include <Wt/Dbo/Exception.h>
 #include <iostream>
-#include <boost/lexical_cast.hpp>
+#include <type_traits>
 
 namespace Wt {
   namespace Dbo {
@@ -76,20 +76,20 @@ void InitSchema::actId(ptr<C>& value, const std::string& name, int size,
 template<typename V>
 void InitSchema::act(const FieldRef<V>& field)
 {
-  int flags = FieldInfo::Mutable | FieldInfo::NeedsQuotes;
+  int flags = FieldFlags::Mutable | FieldFlags::NeedsQuotes;
 
   if (idField_)
-    flags |= FieldInfo::NaturalId; // Natural id
+    flags |= FieldFlags::NaturalId; // Natural id
 
   if ((field.flags() & FieldRef<V>::AuxId) || (fkFlags_ & PtrRef<V>::AuxId))
-    flags |= FieldInfo::AuxId; // Aux id (appended in update and delete)
+    flags |= FieldFlags::AuxId; // Aux id (appended in update and delete)
   
   if (!foreignKeyName_.empty())
     // Foreign key
     mapping_.fields.push_back
       (FieldInfo(field.name(), &typeid(V), field.sqlType(session_),
 		 foreignKeyTable_, foreignKeyName_,
-		 flags | FieldInfo::ForeignKey, fkConstraints_));
+		 flags | FieldFlags::ForeignKey, fkConstraints_));
   else
     // Normal field
     mapping_.fields.push_back
@@ -161,24 +161,24 @@ void DropSchema::visit(C& obj)
 }
 
 template<typename V>
-void DropSchema::actId(V& value, const std::string& name, int size)
+void DropSchema::actId(V& /* value */, const std::string& /* name */, int /* size */)
 { }
 
 template<class C>
-void DropSchema::actId(ptr<C>& value, const std::string& name, int size,
-		       int fkConstraints)
+void DropSchema::actId(ptr<C>& /* value */, const std::string& /* name */, int /* size */,
+		       int /* fkConstraints */)
 { }
 
 template<typename V>
-void DropSchema::act(const FieldRef<V>& field)
+void DropSchema::act(const FieldRef<V>& /* field */)
 { }
 
 template<class C>
-void DropSchema::actPtr(const PtrRef<C>& field)
+void DropSchema::actPtr(const PtrRef<C>& /* field */)
 { }
 
 template<class C>
-void DropSchema::actWeakPtr(const WeakPtrRef<C>& field)
+void DropSchema::actWeakPtr(const WeakPtrRef<C>& /* field */)
 { 
   const char *tableName = session_.tableName<C>();
   if (tablesDropped_.count(tableName) == 0) {
@@ -300,8 +300,8 @@ void LoadDbAction<C>::visit(C& obj)
     statement_->execute();
 
     if (!statement_->nextRow()) {
-      throw ObjectNotFoundException(session->template tableName<C>(), 
-				    boost::lexical_cast<std::string>(dbo_.id()));
+      throw ObjectNotFoundException(session->template tableName<C>(),
+                                    dbo_.idStr());
     }
   }
 
@@ -310,8 +310,7 @@ void LoadDbAction<C>::visit(C& obj)
   persist<C>::apply(obj, *this);
 
   if (!continueStatement && statement_->nextRow())
-    throw Exception("Dbo load: multiple rows for id "
-		    + boost::lexical_cast<std::string>(dbo_.id()) + " ??");
+    throw Exception("Dbo load: multiple rows for id " + dbo_.idStr());
 
   if (continueStatement)
     use(0);
@@ -555,12 +554,9 @@ void SaveDbAction<C>::visit(C& obj)
     if (!isInsert_) {
       int modifiedCount = statement_->affectedRowCount();
       if (modifiedCount != 1 && mapping().versionFieldName) {
-	MetaDbo<C>& dbo = static_cast< MetaDbo<C>& >(dbo_);
-	std::string idString = boost::lexical_cast<std::string>(dbo.id());
-
-	throw StaleObjectException(idString, 
-				   dbo_.session()->template tableName<C>(), 
-				   dbo_.version());
+        throw StaleObjectException(dbo_.idStr(),
+                                   dbo_.session()->template tableName<C>(),
+                                   dbo_.version());
       }
     }
   }
@@ -625,11 +621,11 @@ void TransactionDoneAction::actId(ptr<C>& value, const std::string& name,
 }
 
 template<typename V>
-void TransactionDoneAction::act(const FieldRef<V>& field)
+void TransactionDoneAction::act(const FieldRef<V>& /* field */)
 { }
 
 template<class C>
-void TransactionDoneAction::actPtr(const PtrRef<C>& field)
+void TransactionDoneAction::actPtr(const PtrRef<C>& /* field */)
 { }
 
 template<class C>
@@ -686,11 +682,11 @@ void SessionAddAction::actId(ptr<C>& value, const std::string& name,
 }
 
 template<typename V>
-void SessionAddAction::act(const FieldRef<V>& field)
+void SessionAddAction::act(const FieldRef<V>& /* field */)
 { }
 
 template<class C>
-void SessionAddAction::actPtr(const PtrRef<C>& field)
+void SessionAddAction::actPtr(const PtrRef<C>& /* field */)
 { }
 
 template<class C>
@@ -731,7 +727,7 @@ void SetReciproceAction::actId(ptr<C>& value, const std::string& name,
 }
 
 template<typename V>
-void SetReciproceAction::act(const FieldRef<V>& field)
+void SetReciproceAction::act(const FieldRef<V>& /* field */)
 { }
 
 template<class C>
@@ -742,12 +738,12 @@ void SetReciproceAction::actPtr(const PtrRef<C>& field)
 }
 
 template<class C>
-void SetReciproceAction::actWeakPtr(const WeakPtrRef<C>& field)
+void SetReciproceAction::actWeakPtr(const WeakPtrRef<C>& /* field */)
 {
 }
 
 template<class C>
-void SetReciproceAction::actCollection(const CollectionRef<C>& field)
+void SetReciproceAction::actCollection(const CollectionRef<C>& /* field */)
 {
 }
 
@@ -780,21 +776,21 @@ void ToAnysAction::visit(const ptr<C>& obj)
 template <typename V, class Enable = void>
 struct ToAny
 {
-  static boost::any convert(const V& v) {
+  static cpp17::any convert(const V& v) {
     return v;
   }  
 };
 
 template <typename Enum>
-struct ToAny<Enum, typename boost::enable_if<boost::is_enum<Enum> >::type> 
+struct ToAny<Enum, typename std::enable_if<std::is_enum<Enum>::value>::type> 
 {
-  static boost::any convert(const Enum& v) {
+  static cpp17::any convert(const Enum& v) {
     return static_cast<int>(v);
   }
 };
 
 template <typename V>
-boost::any convertToAny(const V& v) {
+cpp17::any convertToAny(const V& v) {
   return ToAny<V>::convert(v);
 }
 
@@ -815,7 +811,7 @@ template<typename V>
 void ToAnysAction::act(const FieldRef<V>& field)
 { 
   if (allEmpty_)
-    result_.push_back(boost::any());
+    result_.push_back(cpp17::any());
   else
     result_.push_back(convertToAny(field.value()));
 }
@@ -827,11 +823,11 @@ void ToAnysAction::actPtr(const PtrRef<C>& field)
 }
 
 template<class C>
-void ToAnysAction::actWeakPtr(const WeakPtrRef<C>& field)
+void ToAnysAction::actWeakPtr(const WeakPtrRef<C>& /* field */)
 { }
 
 template<class C>
-void ToAnysAction::actCollection(const CollectionRef<C>& field)
+void ToAnysAction::actCollection(const CollectionRef<C>& /* field */)
 { }
 
     /*
@@ -867,16 +863,16 @@ void FromAnyAction::visit(const ptr<C>& obj)
 template <typename V, class Enable = void>
 struct FromAny
 {
-  static V convert(const boost::any& v) {
-    return boost::any_cast<V>(v);
+  static V convert(const cpp17::any& v) {
+    return cpp17::any_cast<V>(v);
   }  
 };
 
 template <typename Enum>
-struct FromAny<Enum, typename boost::enable_if<boost::is_enum<Enum> >::type>
+struct FromAny<Enum, typename std::enable_if<std::is_enum<Enum>::value>::type>
 {
-  static Enum convert(const boost::any& v) {
-    return static_cast<Enum>(boost::any_cast<int>(v));
+  static Enum convert(const cpp17::any& v) {
+    return static_cast<Enum>(cpp17::any_cast<int>(v));
   }
 };
 
@@ -911,11 +907,11 @@ void FromAnyAction::actPtr(const PtrRef<C>& field)
 }
 
 template<class C>
-void FromAnyAction::actWeakPtr(const WeakPtrRef<C>& field)
+void FromAnyAction::actWeakPtr(const WeakPtrRef<C>& /* field */)
 { }
 
 template<class C>
-void FromAnyAction::actCollection(const CollectionRef<C>& field)
+void FromAnyAction::actCollection(const CollectionRef<C>& /* field */)
 { }
 
   }
